@@ -68,7 +68,8 @@ def _expand_arguments_if_necessary(arguments: List[str]) -> List[str]:
 
 
 def _setup_logging(
-    verbosity: int, log_file: Union[str, os.PathLike] = None,
+    verbosity: int,
+    log_file: Union[str, os.PathLike] = None,
 ):
     # TODO(fk) use logging.basicConfig
 
@@ -80,8 +81,10 @@ def _setup_logging(
         file_handler = logging.FileHandler(log_file)
         file_handler.setFormatter(
             logging.Formatter(
-                "%(asctime)s [%(levelname)s](%(name)s:%(funcName)s:%(lineno)d): "
-                "%(message)s"
+                (
+                    "%(asctime)s [%(levelname)s](%(name)s:%(funcName)s:%(lineno)d): "
+                    + "%(message)s"
+                )
             )
         )
         file_handler.setLevel(logging.DEBUG)
