@@ -160,11 +160,11 @@ class Configuration(Serializable):
     generated tests should fit."""
 
     max_recursion: int = 10
-    """Recursion depth when trying to create objects"""
+    """Recursion depth when trying to create objects in a test case."""
 
     max_cluster_recursion: int = 10
     """The maximum level of recursion when calculating the dependencies in the test
-    cluster"""
+    cluster."""
 
     max_delta: int = 20
     """Maximum size of delta for numbers during mutation"""
@@ -176,16 +176,16 @@ class Configuration(Serializable):
     """Maximum length of randomly generated strings"""
 
     primitive_reuse_probability: float = 0.5
-    """Probability to reuse an existing primitive, if available.  Expects values in
-    [0,1]"""
+    """Probability to reuse an existing primitive in a test case, if available.
+    Expects values in [0,1]"""
 
     object_reuse_probability: float = 0.9
-    """Probability to reuse an existing object, if available.  Expects values in
-    [0,1]"""
+    """Probability to reuse an existing object in a test case, if available.
+    Expects values in [0,1]"""
 
     none_probability: float = 0.1
-    """Probability to use None instead of constructing an object.  Expects values in
-    [0,1]"""
+    """Probability to use None in a test case instead of constructing an object.
+    Expects values in [0,1]"""
 
     guess_unknown_types: bool = True
     """Should we guess unknown types while constructing parameters?
@@ -195,8 +195,8 @@ class Configuration(Serializable):
     e.g. Callable[...]"""
 
     change_parameter_probability: float = 0.1
-    """Probability of replacing parameters when mutating a method or constructor statement
-    in a test case.  Expects values in [0,1]"""
+    """Probability of replacing parameters when mutating a method or constructor
+    statement in a test case.  Expects values in [0,1]"""
 
     rank_bias: float = 1.7
     """Bias for better individuals in rank selection"""
@@ -219,6 +219,10 @@ class Configuration(Serializable):
     chromosome_length: int = 40
     """Maximum length of chromosomes during search"""
 
+    max_length_test_case = 2500
+    """The maximum number of statement in as test case (normal + assertion
+    statements)"""
+
     max_attempts: int = 1000
     """Number of attempts when generating an object before giving up"""
 
@@ -259,6 +263,19 @@ class Configuration(Serializable):
     """Should the generator use a static constant seeding technique to improve constant
     generation?"""
 
+    duck_type_analysis: bool = False
+    """Should the duck-type analysis be used for type inference during test
+    generation?"""
+
+    generate_assertions: bool = True
+    """Should assertions be generated?"""
+
+    float_precision: float = 0.01
+    """Precision to use in float comparisons and assertions"""
+
+    duck_mock_module_only: bool = False
+    """Do only parse module dependencies for duck mocks, not whole class path."""
+
 
 # Singleton instance of the configuration.
 INSTANCE = Configuration(
