@@ -39,7 +39,8 @@ class BranchDistanceInstrumentation:
     # As of CPython 3.8, there are a few compare ops for which we can't really
     # compute a sensible branch distance. So for now, we just ignore those
     # comparisons and just track their boolean value.
-    # TODO(fk) update this to work with the bytecode for CPython 3.9, once it is released.
+    # TODO(fk) update this to work with the bytecode for CPython 3.9, once it is
+    #  released.
     _IGNORED_COMPARE_OPS: Set[Compare] = {Compare.EXC_MATCH}
 
     # Conditional jump operations are the last operation within a basic block
@@ -80,7 +81,9 @@ class BranchDistanceInstrumentation:
         return code.replace(co_consts=tuple(new_consts))
 
     def _instrument_code_recursive(
-        self, code: CodeType, parent_code_object_id: Optional[int] = None,
+        self,
+        code: CodeType,
+        parent_code_object_id: Optional[int] = None,
     ) -> CodeType:
         """Instrument the given Code Object recursively.
 
@@ -122,7 +125,7 @@ class BranchDistanceInstrumentation:
         # Required to transform for loops.
         dominator_tree = DominatorTree.compute(cfg)
         # Attributes which store the predicate ids assigned to instrumented nodes.
-        node_attributes: Dict[ProgramGraphNode, Dict[str, int]] = dict()
+        node_attributes: Dict[ProgramGraphNode, Dict[str, int]] = {}
         for node in cfg.nodes:
             predicate_id = self._instrument_node(
                 cfg, code_object_id, dominator_tree, node
@@ -159,9 +162,11 @@ class BranchDistanceInstrumentation:
             ), "Non artificial node does not have a basic block."
             assert len(node.basic_block) > 0, "Empty basic block in CFG."
             maybe_jump: Instr = node.basic_block[self._JUMP_OP_POS]
-            maybe_compare: Optional[Instr] = node.basic_block[
-                self._COMPARE_OP_POS
-            ] if len(node.basic_block) > 1 else None
+            maybe_compare: Optional[Instr] = (
+                node.basic_block[self._COMPARE_OP_POS]
+                if len(node.basic_block) > 1
+                else None
+            )
             if isinstance(maybe_jump, Instr):
                 if maybe_jump.name == "FOR_ITER":
                     predicate_id = self._instrument_for_loop(
@@ -178,13 +183,13 @@ class BranchDistanceInstrumentation:
     ) -> int:
         """Instrument a conditional jump.
 
-        If it is based on a prior comparision, we track
+        If it is based on a prior comparison, we track
         the compared values, otherwise we just track the truthiness of the value on top
         of the stack.
 
         Args:
             code_object_id: The id of the containing Code Object.
-            maybe_compare: The comparision operation, if any.
+            maybe_compare: The comparison operation, if any.
             block: The containing basic block.
 
         Returns:
@@ -246,7 +251,7 @@ class BranchDistanceInstrumentation:
         """Instrument compare-based conditional jumps.
 
         We add a call to the tracer which reports the values that will be used
-        in the following comparision operation on which the conditional jump is based.
+        in the following comparison operation on which the conditional jump is based.
 
         Args:
             block: The containing basic block.
