@@ -6,8 +6,9 @@
 #
 """Provides a visitor that transforms test cases to asts."""
 from ast import stmt
-from typing import List
+from typing import List, Set
 
+import pynguin.assertion.assertion_to_ast as ata
 import pynguin.testcase.defaulttestcase as dtc
 import pynguin.testcase.statement_to_ast as stmt_to_ast
 from pynguin.testcase.testcasevisitor import TestCaseVisitor
@@ -15,9 +16,10 @@ from pynguin.utils.namingscope import NamingScope
 
 
 class TestCaseToAstVisitor(TestCaseVisitor):
-    """
-    A test case visitor that transforms an arbitrary number of test case to ast statements.
-    The modules that are required by the individual test cases are gathered and given an alias.
+    """Transforms an arbitrary number of test cases to AST statements.
+
+    The modules that are required by the individual test cases are gathered and given
+    an alias.
     """
 
     def __init__(self, wrap_code: bool = False) -> None:
@@ -27,15 +29,25 @@ class TestCaseToAstVisitor(TestCaseVisitor):
             wrap_code: Whether or not exported code shall be wrapped
         """
         self._module_aliases = NamingScope("module")
+        # Common modules (e.g. math) are not aliased.
+        self._common_modules: Set[str] = set()
         self._test_case_asts: List[List[stmt]] = []
         self._wrap_code = wrap_code
 
     def visit_default_test_case(self, test_case: dtc.DefaultTestCase) -> None:
+        variables = NamingScope()
         statement_visitor = stmt_to_ast.StatementToAstVisitor(
-            self._module_aliases, NamingScope(), self._wrap_code
+            self._module_aliases, variables, self._wrap_code
         )
         for statement in test_case.statements:
             statement.accept(statement_visitor)
+            # TODO(fk) better way. Nest visitors?
+            assertion_visitor = ata.AssertionToAstVisitor(
+                self._common_modules, variables
+            )
+            for assertion in statement.assertions:
+                assertion.accept(assertion_visitor)
+            statement_visitor.append_nodes(assertion_visitor.nodes)
         self._test_case_asts.append(statement_visitor.ast_nodes)
 
     @property
@@ -55,3 +67,13 @@ class TestCaseToAstVisitor(TestCaseVisitor):
             The module aliases
         """
         return self._module_aliases
+
+    @property
+    def common_modules(self) -> Set[str]:
+        """Provides the common modules that were used when transforming all test cases.
+        This is used, because common modules (e.g., math) should not be aliased.
+
+        Returns:
+            A set of the modules names
+        """
+        return self._common_modules
